pub struct RenderOptions {
pub use_color: bool,
pub use_hyperlinks: bool,
}Expand description
Options that control how a report is rendered.
The default is CI-friendly (no colour, no hyperlinks).
Fields
use_color: boolWhen true, ANSI colour escape codes are emitted in terminal output.
When false, output is plain ASCII.
use_hyperlinks: boolWhen true, file paths in terminal output are wrapped in OSC-8 hyperlinks.